@@ -13,11 +13,12 @@ from prompt_toolkit.patch_stdout import patch_stdout
 from rich.markup import escape as rich_escape
 from yarl import URL
 
-from neuro_sdk import DEFAULT_API_URL, ConfigError
+from neuro_sdk import DEFAULT_API_URL, AuthorizationError, ConfigError
 
-from neuro_cli.formatters.config import ClustersFormatter, QuotaFormatter
+from neuro_cli.formatters.config import ClustersFormatter
 
 from .alias import list_aliases
+from .click_types import CLUSTER, ORG
 from .formatters.config import AliasesFormatter, ConfigFormatter
 from .root import Root
 from .utils import argument, command, group, option
@@ -37,9 +38,10 @@ async def show(root: Root) -> None:
     fmt = ConfigFormatter()
     try:
         jobs_capacity = await root.client.jobs.get_capacity(cluster_name=cluster_name)
-    except ClientConnectionError:
+    except (ClientConnectionError, AuthorizationError):
         jobs_capacity = {}
-    root.print(fmt(root.client.config, jobs_capacity))
+    quota = await root.client.users.get_quota()
+    root.print(fmt(root.client.config, jobs_capacity, quota))
 
 
 @command()
@@ -50,38 +52,6 @@ async def show_token(root: Root) -> None:
     root.print(await root.client.config.token(), soft_wrap=True)
 
 
-@command()
-@argument("user", required=False, default=None, type=str)
-async def show_quota(root: Root, user: Optional[str]) -> None:
-    """
-    Print quota and remaining computation time for active cluster.
-    """
-    username = user or root.client.config.username
-    quotas = await root.client._users.get_quota(username)
-    cluster_name = root.client.config.cluster_name
-    if cluster_name not in quotas:
-        raise ValueError(
-            f"No quota information available for cluster {cluster_name}.\n"
-            "Please logout and login again."
-        )
-    cluster_quota = quotas[cluster_name]
-    fmt = QuotaFormatter()
-    root.print(fmt(cluster_quota))
-
-
-@command()
-async def add_quota(root: Root) -> None:
-    """
-    Print instructions for increasing quota for current user
-    """
-    user_name = root.client.config.username
-    cluster_name = root.client.config.cluster_name
-    root.print(
-        f"In order to increase your quota, please navigate to "
-        f"https://neuro.payments.com/{user_name}/{cluster_name}?pay=usd100"
-    )
-
-
 def _print_welcome(root: Root, url: URL) -> None:
     root.print(f"Logged into {url}")
     root.print(
@@ -141,7 +111,7 @@ async def login_with_token(root: Root, token: str, url: URL) -> None:
 @argument("url", required=False, default=DEFAULT_API_URL, type=URL)
 async def login_headless(root: Root, url: URL) -> None:
     """
-    Log into Neuro Platform from non-GUI server environment.
+    Log into Neuro Platform in non-GUI environ
 
     URL is a platform entrypoint URL.
 
@@ -201,7 +171,10 @@ async def aliases(root: Root) -> None:
 )
 async def docker(root: Root, docker_config: str) -> None:
     """
-    Configure docker client to fit the Neuro Platform.
+    Configure local docker client
+
+    This command configures local docker client to
+    use Neuro Platform's docker registry.
     """
     config_path = Path(docker_config)
     if not config_path.exists():
@@ -233,8 +206,10 @@ async def docker(root: Root, docker_config: str) -> None:
 @command()
 async def get_clusters(root: Root) -> None:
     """
-    Fetch and display the list of available clusters.
+    List available clusters/org pairs.
 
+    This command re-fetches cluster list and then displays each
+    cluster with available orgs.
     """
 
     with root.status("Fetching the list of available clusters"):
@@ -242,12 +217,16 @@ async def get_clusters(root: Root) -> None:
     fmt = ClustersFormatter()
     with root.pager():
         root.print(
-            fmt(root.client.config.clusters.values(), root.client.config.cluster_name)
+            fmt(
+                root.client.config.clusters.values(),
+                root.client.config.cluster_name,
+                root.client.config.org_name,
+            )
         )
 
 
 @command()
-@argument("cluster_name", required=False, default=None, type=str)
+@argument("cluster_name", required=False, default=None, type=CLUSTER)
 async def switch_cluster(root: Root, cluster_name: Optional[str]) -> None:
     """Switch the active cluster.
 
@@ -272,6 +251,25 @@ async def switch_cluster(root: Root, cluster_name: Optional[str]) -> None:
     )
 
 
+@command()
+@argument("org_name", required=True, type=ORG)
+async def switch_org(root: Root, org_name: Optional[str]) -> None:
+    """Switch the active organization.
+
+    ORG_NAME is the organization name to select. Use literal "NO_ORG" to switch
+    to using current cluster directly instead of on behalf of some org.
+    """
+    with root.status("Fetching the list of available cluster/org pairs"):
+        await root.client.config.fetch()
+    if org_name == ORG.NO_ORG_STR:
+        org_name = None
+    await root.client.config.switch_org(org_name)
+    root.print(
+        f"The current org_name is [u]{rich_escape(org_name or '<no-org>')}[/u]",
+        markup=True,
+    )
+
+
 async def prompt_cluster(
     root: Root, *, session: Optional[PromptSession[str]] = None
 ) -> str:
@@ -280,7 +278,13 @@ async def prompt_cluster(
     clusters = root.client.config.clusters
     while True:
         fmt = ClustersFormatter()
-        root.print(fmt(clusters.values(), root.client.config.cluster_name))
+        root.print(
+            fmt(
+                clusters.values(),
+                root.client.config.cluster_name,
+                root.client.config.org_name,
+            )
+        )
         with patch_stdout():
             answer = await session.prompt_async(
                 f"Select cluster to switch [{root.client.config.cluster_name}]: "
@@ -303,10 +307,10 @@ config.add_command(login_with_token)
 config.add_command(login_headless)
 config.add_command(show)
 config.add_command(show_token)
-config.add_command(show_quota)
 config.add_command(aliases)
 config.add_command(get_clusters)
 config.add_command(switch_cluster)
+config.add_command(switch_org)
 
 config.add_command(docker)
 
