@@ -77,7 +77,7 @@ def test_job_run(helper: Helper) -> None:
         [
             "job",
             "run",
-            "--http",
+            "--http-port",
             "80",
             "--no-wait-start",
             "--restart",
@@ -159,7 +159,7 @@ def test_job_description(helper: Helper) -> None:
         [
             "job",
             "run",
-            "--http",
+            "--http-port",
             "80",
             "--description",
             description,
@@ -191,36 +191,6 @@ def test_job_description(helper: Helper) -> None:
     helper.kill_job(job_id, wait=False)
 
 
-@pytest.mark.skip(reason="'neuro job tags' is slow and will be deprecated")
-@pytest.mark.e2e
-def test_job_tags(helper: Helper) -> None:
-    tags = [f"test-tag:{uuid4()}", "test-tag:common"]
-    tag_options = [key for pair in [("--tag", t) for t in tags] for key in pair]
-
-    command = "sleep 10m"
-    captured = helper.run_cli(
-        [
-            "job",
-            "run",
-            *tag_options,
-            "--no-wait-start",
-            UBUNTU_IMAGE_NAME,
-            "--",
-            command,
-        ]
-    )
-    match = re.match("Job ID: (.+)", captured.out)
-    assert match is not None
-    job_id = match.group(1)
-
-    captured = helper.run_cli(["-q", "ps", *tag_options])
-    assert job_id in captured.out
-
-    captured = helper.run_cli(["job", "tags"])
-    tags_listed = [tag.strip() for tag in captured.out.split("\n")]
-    assert set(tags) <= set(tags_listed)
-
-
 @pytest.mark.e2e
 def test_job_filter_by_date_range(helper: Helper) -> None:
     captured = helper.run_cli(
@@ -827,10 +797,10 @@ def test_pass_config(helper: Helper) -> None:
 def test_job_submit_bad_http_auth(helper: Helper, http_auth: str) -> None:
     with pytest.raises(subprocess.CalledProcessError) as cm:
         helper.run_cli(
-            ["job", "run", "--http=0", http_auth, UBUNTU_IMAGE_NAME, "--", "true"]
+            ["job", "run", "--http-port=0", http_auth, UBUNTU_IMAGE_NAME, "--", "true"]
         )
     assert cm.value.returncode == 2
-    assert f"{http_auth} requires --http" in cm.value.stderr
+    assert f"{http_auth} requires --http-port" in cm.value.stderr
 
 
 @pytest.fixture
@@ -895,7 +865,7 @@ def test_job_submit_no_detach_failure(helper: Helper) -> None:
                 "-v",
                 "job",
                 "run",
-                "--http",
+                "--http-port",
                 "80",
                 UBUNTU_IMAGE_NAME,
                 "--",
