@@ -19,6 +19,7 @@ from neuro_cli import __version__
 from neuro_cli.const import EX_OK
 from neuro_cli.main import main
 from neuro_cli.root import Root
+from neuro_cli.utils import Command, Context
 
 SysCapWithCode = namedtuple("SysCapWithCode", ["out", "err", "code"])
 log = logging.getLogger(__name__)
@@ -58,6 +59,7 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
             ),
         },
         name="default",
+        orgs=[None],
     )
     cluster2_config = Cluster(
         registry_url=URL("https://registry2-dev.neu.ro"),
@@ -73,6 +75,7 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
             ),
         },
         name="other",
+        orgs=[None],
     )
     config = _ConfigData(
         auth_config=auth_config,
@@ -80,7 +83,8 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
         url=URL("https://dev.neu.ro/api/v1"),
         admin_url=URL("https://dev.neu.ro/apis/admin/v1"),
         version=__version__,
-        cluster_name="default",
+        cluster_name=cluster_config.name,
+        org_name=cluster_config.orgs[0],
         clusters={
             cluster_config.name: cluster_config,
             cluster2_config.name: cluster2_config,
@@ -91,6 +95,9 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
 
 
 def create_root(config_path: Path) -> Root:
+    async def cmd() -> None:
+        pass
+
     return Root(
         color=False,
         tty=False,
@@ -106,6 +113,7 @@ def create_root(config_path: Path) -> Root:
         skip_gmp_stats=True,
         show_traceback=False,
         iso_datetime_format=False,
+        ctx=Context(Command(cmd, name="")),
     )
 
 
