@@ -309,7 +309,58 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
+            )(description)
+        )
+
+    def test_job_with_org_urls(
+        self, rich_cmp: Any, datetime_formatter: DatetimeFormatter
+    ) -> None:
+        description = JobDescription(
+            status=JobStatus.FAILED,
+            owner="test-user",
+            cluster_name="default",
+            org_name="test-org",
+            id="test-job",
+            uri=URL("job://default/test-org/test-user/test-job"),
+            name="test-job-name",
+            description="test job description",
+            http_url=URL("http://local.host.test/"),
+            history=JobStatusHistory(
+                status=JobStatus.PENDING,
+                reason="ErrorReason",
+                description="ErrorDesc",
+                created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
+                started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
+                finished_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
+                exit_code=123,
+            ),
+            container=Container(
+                command="test-command",
+                image=RemoteImage.new_external_image(name="test-image"),
+                resources=Resources(16, 0.1, 0, None, False, None, None),
+                http=HTTPPort(port=80, requires_auth=True),
+                volumes=[
+                    Volume(
+                        storage_uri=URL("storage://default/test-org/test-user/folder"),
+                        container_path="/mnt/storage",
+                    )
+                ],
+            ),
+            scheduler_enabled=False,
+            pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
+        )
+
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="default", org_name="test-org"
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -349,7 +400,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -389,7 +442,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -429,7 +484,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -469,7 +526,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -510,7 +569,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -549,7 +610,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -585,7 +648,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -622,7 +687,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -658,7 +725,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -696,7 +765,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -755,7 +826,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -795,7 +868,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -834,7 +909,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -870,6 +947,7 @@ class TestJobOutputFormatter:
                     registry="https://registry.neu.ro",
                     owner="test-user",
                     cluster_name="test-cluster",
+                    org_name=None,
                 ),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
@@ -881,7 +959,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -917,6 +997,7 @@ class TestJobOutputFormatter:
                     registry="https://registry.neu.ro",
                     owner="test-user",
                     cluster_name="test-cluster",
+                    org_name=None,
                 ),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
@@ -944,7 +1025,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -980,6 +1063,7 @@ class TestJobOutputFormatter:
                     registry="https://registry.neu.ro",
                     owner="test-user",
                     cluster_name="test-cluster",
+                    org_name=None,
                 ),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
@@ -1037,6 +1121,7 @@ class TestJobOutputFormatter:
                     registry="https://registry.neu.ro",
                     owner="test-user",
                     cluster_name="test-cluster",
+                    org_name=None,
                 ),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
@@ -1074,7 +1159,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -1110,6 +1197,7 @@ class TestJobOutputFormatter:
                     registry="https://registry.neu.ro",
                     owner="test-user",
                     cluster_name="test-cluster",
+                    org_name=None,
                 ),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
@@ -1137,7 +1225,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -1173,6 +1263,7 @@ class TestJobOutputFormatter:
                     registry="https://registry.neu.ro",
                     owner="test-user",
                     cluster_name="test-cluster",
+                    org_name=None,
                 ),
                 working_dir="/working/dir",
                 resources=Resources(16, 0.1, 0, None, False, None, None),
@@ -1184,7 +1275,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -1221,7 +1314,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -1258,7 +1353,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -1296,7 +1393,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal("15"),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -1334,7 +1433,9 @@ class TestJobOutputFormatter:
             price_credits_per_hour=Decimal(15 / 15000),
         )
 
-        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        uri_fmtr = uri_formatter(
+            username="test-user", cluster_name="test-cluster", org_name=None
+        )
         rich_cmp(
             JobStatusFormatter(
                 uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
@@ -1698,7 +1799,7 @@ class TestTabularJobRow:
     def test_image_from_registry_parsing_short(
         self, root: Root, datetime_formatter: DatetimeFormatter
     ) -> None:
-        uri_fmtr = uri_formatter(username="bob", cluster_name="default")
+        uri_fmtr = uri_formatter(username="bob", cluster_name="default", org_name=None)
         image_fmtr = image_formatter(uri_formatter=uri_fmtr)
         row = TabularJobRow.from_job(
             self._job_descr_with_status(
@@ -1865,6 +1966,7 @@ class TestTabularJobsFormatter:
                         registry="https://registry.neu.ro",
                         owner="bob",
                         cluster_name="test-cluster",
+                        org_name=None,
                     ),
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                     command="ls -la /some/path",
